summaryrefslogtreecommitdiffstats
path: root/kplato/kptnode.h
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kptnode.h')
-rw-r--r--kplato/kptnode.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kplato/kptnode.h b/kplato/kptnode.h
index 95d7c24b..10c5613f 100644
--- a/kplato/kptnode.h
+++ b/kplato/kptnode.h
@@ -91,7 +91,7 @@ public:
virtual bool load(TQDomElement &) { return true; }
virtual bool load(TQDomElement &, Project &) { return true; }
virtual void save(TQDomElement &element) const = 0;
- /// Save my and my tqchildrens relations.
+ /// Save my and my childrens relations.
virtual void saveRelations(TQDomElement &element) const;
// simple child node management
@@ -458,7 +458,7 @@ public:
void setRunningAccount(Account *acc) { m_runningAccount = acc; }
Schedule *currentSchedule() const { return m_currentSchedule; }
/// Set current schedule to schedule with identity id, for me and my tqchildren
virtual void setCurrentSchedule(long id);
// NOTE: Cannot use setCurrentSchedule() due to overload/casting problems
void setCurrentSchedulePtr(Schedule *schedule) { m_currentSchedule = schedule; }
@@ -541,7 +541,7 @@ private:
#ifndef NDEBUG
public:
- virtual void printDebug(bool tqchildren, TQCString indent);
+ virtual void printDebug(bool children, TQCString indent);
#endif
};
@@ -458,7 +458,7 @@ public:
void setRunningAccount(Account *acc) { m_runningAccount = acc; }
Schedule *currentSchedule() const { return m_currentSchedule; }
- /// Set current schedule to schedule with identity id, for me and my tqchildren
+ /// Set current schedule to schedule with identity id, for me and my children
virtual void setCurrentSchedule(long id);
// NOTE: Cannot use setCurrentSchedule() due to overload/casting problems